@@ -56,7 +56,9 @@ class B8(Gtk.Application, logs.LoggerMixin):
     self.vim.connect('ready', self._on_vim_ready)
     self.buffers = buffers.Buffers()
     self.files = files.Files()
-    self.terminals = terminals.Terminals()
+    self.terminals = terminals.Terminals(
+        font=self.config.get(('terminal', 'font'))
+    )
     self.connect('activate', self._on_activate)
 
     for w in [self.buffers, self.files, self.terminals]:
@@ -142,6 +144,7 @@ class B8(Gtk.Application, logs.LoggerMixin):
       return True
 
   def _on_vim_ready(self, w):
+    self.debug('vim is ready')
     self.window.show_all()
     self.vim.grab_focus()
     self.window.present()
